@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.86'; # VERSION
+our $DATE = '2015-02-26'; # DATE
+our $VERSION = '0.87'; # VERSION
 
 use 5.010001;
 use strict;
@@ -342,8 +342,7 @@ sub get_subcommand_data {
 
 sub list_subcommands {
     my ($self) = @_;
-    state $cached;
-    return $cached if $cached;
+    return $self->{_cache_subcommands} if $self->{_cache_subcommands};
 
     my $scs = $self->subcommands;
     my $res;
@@ -357,7 +356,8 @@ sub list_subcommands {
     } else {
         $res = {};
     }
-    $cached = $res;
+    $self->{_cache_subcommands} = $res;
+    $res;
 }
 
 sub status2exitcode {
@@ -1142,7 +1142,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.86 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-24.
+This document describes version 0.87 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-26.
 
 =head1 DESCRIPTION
 
