@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.86'; # VERSION
+our $DATE = '2015-02-26'; # DATE
+our $VERSION = '0.87'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -439,7 +439,7 @@ sub run_help {
         program_summary => ($scd ? $scd->{summary}:undef ) // $meta->{summary},
         program_description => $scd ? $scd->{description} : undef,
         meta => $meta,
-        subcommands => $has_sc_no_sc ? $self->subcommands : undef,
+        subcommands => $has_sc_no_sc ? $self->list_subcommands : undef,
         common_opts => $common_opts,
         per_arg_json => $self->per_arg_json,
         per_arg_yaml => $self->per_arg_yaml,
@@ -491,7 +491,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.86 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-24.
+This document describes version 0.87 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-26.
 
 =head1 SYNOPSIS
 
